APPLICATION

Struct APPLICATION 

pub struct APPLICATION { /* private fields */ }
Application state

Methods from Deref<Target = Lock<CargoMoveApp>>

pub fn read(&'static self) -> Reader<A>

Get the global application state, acquiring a shared, read-only lock around it which permits concurrent access by multiple readers.

If the application has not yet been initialized, calls not_loaded().

pub fn write(&'static self) -> Writer<A>

Obtain an exclusive lock on the application state, allowing it to be accessed mutably.

pub fn set(&self, new_app: A)

Set the global application state to the given value