pub struct APPLICATION { /* private fields */ }Expand description
Application state
Methods from Deref<Target = Lock<CargoMoveApp>>
Sourcepub fn read(&'static self) -> Reader<A>
pub fn read(&'static self) -> Reader<A>
Get the global application state, acquiring a shared, read-only lock around it which permits concurrent access by multiple readers.
If the application has not yet been initialized, calls not_loaded().